---
id: 101
properties:
- id: priority
  name: testy
  type: string
  value: Medium
- id: done
  name: Done
  type: boolean
  value: false
- id: status
  name: Status
  type: status
  value: Not Started
---

Call Dr. Martin's office to book a cleaning. Last visit was 6 months ago.

Phone: 555-0123